@@ -20,6 +20,8 @@ def saveDate(option,conversion_filepath,customer_filepath):
     columns6 = book['地区'].columns
     columns7 = book['负责部门'].columns
     columns8 = book['供应商等级'].columns
+    columns9 = book['供应类别'].columns
+    columns10 = book['发票类型'].columns
 
     headers1 = [cell.value for cell in next(columns1)]
     headers2 = [cell.value for cell in next(columns2)]
@@ -29,6 +31,8 @@ def saveDate(option,conversion_filepath,customer_filepath):
     headers6 = [cell.value for cell in next(columns6)]
     headers7 = [cell.value for cell in next(columns7)]
     headers8 = [cell.value for cell in next(columns8)]
+    headers9 = [cell.value for cell in next(columns9)]
+    headers10 = [cell.value for cell in next(columns10)]
 
     currencyDict = []
     methodDict = []
@@ -38,6 +42,8 @@ def saveDate(option,conversion_filepath,customer_filepath):
     regionDict = []
     departmentDict = []
     gradeDict = []
+    supplyclassifyDict = []
+    invoicetypeDict = []
 
     for col1 in columns1:
         data1 = {}
@@ -79,6 +85,16 @@ def saveDate(option,conversion_filepath,customer_filepath):
         for title, cell in zip(headers8, col8):
             data8[title] = cell.value
         gradeDict.append(data8)
+    for col9 in columns9:
+        data9 = {}
+        for title, cell in zip(headers9, col9):
+            data9[title] = cell.value
+        supplyclassifyDict.append(data9)
+    for col10 in columns10:
+        data10 = {}
+        for title, cell in zip(headers10, col10):
+            data10[title] = cell.value
+        invoicetypeDict.append(data10)
 
     # print(currencyDict[0])
     # print(methodDict[0])
@@ -119,6 +135,16 @@ def saveDate(option,conversion_filepath,customer_filepath):
         department1 = departmentDict[0][department]
         grade = df.loc[i]['供应商等级']
         grade1 = gradeDict[0][grade]
+        supplyclassify = df.loc[i]['供应类别']
+        supplyclassify1 = supplyclassifyDict[0][supplyclassify]
+        if df.loc[i]['发票类型'] != '':
+            invoicetype = df.loc[i]['发票类型']
+            invoicetype1 = invoicetypeDict[0][invoicetype]
+        else:
+            invoicetype1 = df.loc[i]['发票类型']
+
+
+
         data = {
             "FCreateOrgId": 100,
 
@@ -131,20 +157,20 @@ def saveDate(option,conversion_filepath,customer_filepath):
             "FSOCIALCRECODE": df.loc[i]['统一社会信用代码'],
             "FRegisterAddress": df.loc[i]['注册地址'],
             "FDeptId": department1,
-            "FSupplyClassify": df.loc[i]['供应商分类'],
+            "FSupplyClassify": supplyclassify1,
             "FSupplierGrade": grade1,
             "FSettleTypeId": method1,
             "FPayCurrencyId": currency1,
             "FPayCondition": payment1,
             # "FTaxType": df.loc[i]['税分类'],
-            "FInvoiceType": df.loc[i]['发票类型'],
+            "FInvoiceType": invoicetype1,
             "FTaxRateId": rate1,
             # "FBankCode": df.loc[i]['银行账号'],
             "FBankHolder": df.loc[i]['账户名称'],
             "FOpenAddressRec": df.loc[i]['开户行地址'],
             "FOpenBankName": df.loc[i]['开户银行'],
             "FCNAPS": df.loc[i]['联行号'],
-            "FBankCurrencyId": df.loc[i]['币别'],
+            "FBankCurrencyId": currency1,
 
 
         }
